<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Schlagworte und Schlagwortgruppen',
	'mots_slogan' => 'Verwaltung von Schlagworten und Schlagwortgruppen mit  SPIP',
];
